# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [v2.0.2](https://github.com/velez94/validate-aws-policies/releases/tag/v2.0.2) - 2024-09-22

<small>[Compare with first commit](https://github.com/velez94/validate-aws-policies/compare/a143292bbc3b4150258d65d243f37c317f14854b...v2.0.2)</small>

### Bug Fixes

- modify flag to upload reports to S3 ([0026e3a](https://github.com/velez94/validate-aws-policies/commit/0026e3ac5ae795ecce3bc78becbfca63b824a4a5) by alejandro.velez).
- fix description for commands ([d9dc9f9](https://github.com/velez94/validate-aws-policies/commit/d9dc9f9bd4978f319afdab758794c2907261786c) by alejandro.velez).

### Docs

- update readme ([14c7f0a](https://github.com/velez94/validate-aws-policies/commit/14c7f0a283c74fdf13a6a61f3dab18e8ea5a95de) by alejandro.velez).

